@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright(C) 2018      Vincent Ardisson
 #
 # This file is part of woob.
@@ -17,8 +15,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with woob. If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import unicode_literals, absolute_import
-
 import codecs
 from collections import OrderedDict
 from contextlib import contextmanager
@@ -64,19 +60,19 @@ __all__ = (
 )
 
 
-class CustomCondition(object):
+class CustomCondition:
     """Abstract condition class
 
     In Selenium, waiting is done on callable objects named "conditions".
     Basically, a condition is a function predicate returning True if some condition is met.
 
-    The builtin selenium conditions are in :any:`selenium.webdriver.support.expected_conditions`.
+    The builtin selenium conditions are in :meth:`selenium.webdriver.support.expected_conditions`.
 
-    This class exists to differentiate normal methods from condition objects when calling :any:`SeleniumPage.is_here`.
+    This class exists to differentiate normal methods from condition objects when calling :math:`SeleniumPage.is_here`.
 
     See https://seleniumhq.github.io/selenium/docs/api/py/webdriver_support/selenium.webdriver.support.expected_conditions.html
     When using `selenium.webdriver.support.expected_conditions`, it's better to
-    wrap them using :any:`WrapException`.
+    wrap them using :class:`WrapException`.
     """
 
     def __call__(self, driver):
@@ -250,7 +246,7 @@ def link_locator(text, partial=False):
         return (By.LINK_TEXT, text)
 
 
-class ElementWrapper(object):
+class ElementWrapper:
     """Wrapper to Selenium element to ressemble lxml.
 
     Some differences:
@@ -286,7 +282,7 @@ class ElementWrapper(object):
         return getattr(self.wrapped, attr)
 
     @property
-    class attrib(object):
+    class attrib:
         def __init__(self, el):
             self.el = el
 
@@ -303,7 +299,7 @@ class ElementWrapper(object):
             return v
 
 
-class SeleniumPage(object):
+class SeleniumPage:
     """Page to use in a SeleniumBrowser
 
     Differences with regular woob Pages:
@@ -330,7 +326,7 @@ class SeleniumPage(object):
         Make sure the page is "ready" for the usage we want. For example, if there's
         a splash screen in front the page, preventing click, it should return False.
 
-        `is_here` can be a method or a :any:`CustomCondition` instance.
+        `is_here` can be a method or a :class:`CustomCondition` instance.
         """
         return True
 
@@ -375,7 +371,7 @@ class DirFirefoxProfile(FirefoxProfile):
         return super(DirFirefoxProfile, self)._create_tempfolder()
 
 
-class FakeResponse(object):
+class FakeResponse:
     page = None
 
     def __init__(self, **kwargs):
@@ -390,14 +386,14 @@ class SeleniumBrowserSetupError(Exception):
     """
 
 
-class SeleniumBrowser(object):
+class SeleniumBrowser:
     """Browser similar to PagesBrowser, but using Selenium.
 
     URLs instances can be used. The need_login decorator can be used too.
 
     Differences:
     - since JS code can be run anytime, the current `url` and `page` can change anytime
-    - it's not possible to use `open()`, only `location()` can be used
+    - it's not possible to use :meth:`open()`, only :meth:`location()` can be used
     - many options are not implemented yet (like proxies) or cannot be implemented at all
     """
 
@@ -593,17 +589,21 @@ class SeleniumBrowser(object):
         self.logger.debug('Unable to handle %s', self.url)
 
     def open(self, *args, **kwargs):
+        """
+        Raises :class:`NotImplementedError`.
+        """
         # TODO maybe implement with a new window?
         raise NotImplementedError()
 
     def location(self, url, data=None, headers=None, params=None, method=None, json=None):
-        """Change current url of the browser.
+        """
+        Change current url of the browser.
 
         Warning: unlike other requests-based woob browsers, this function does not block
         until the page is loaded, it's completely asynchronous.
         To use the new page content, it's necessary to wait, either implicitly (e.g. with
-        context manager :any:`implicit_wait`) or explicitly (e.g. using method
-        :any:`wait_until`)
+        context manager :meth:`implicit_wait`) or explicitly (e.g. using method
+        :meth:`wait_until`)
         """
         assert method is None
         assert data is None
@@ -700,7 +700,7 @@ class SeleniumBrowser(object):
         Wraps WebDriverWait.
         See https://seleniumhq.github.io/selenium/docs/api/py/webdriver_support/selenium.webdriver.support.wait.html
 
-        See :any:`CustomCondition`.
+        See :class:`CustomCondition`.
 
         :param timeout: wait time in seconds (else DEFAULT_WAIT if None)
         """
@@ -805,7 +805,7 @@ class SeleniumBrowser(object):
         self.driver.execute(Command.CLEAR_LOCAL_STORAGE)
 
 
-class SubSeleniumMixin(object):
+class SubSeleniumMixin:
     """Mixin to have a Selenium browser for performing login."""
 
     SELENIUM_BROWSER = None
