@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright(C) 2010-2016 Romain Bignon
 #
 # This file is part of woob.
@@ -17,15 +15,17 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with woob. If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import annotations
 
 from binascii import crc32
 import re
+from typing import Iterable, List
 
 from woob.capabilities.account import CapCredentialsCheck
 from woob.capabilities.base import (
     BaseObject, Capability, Field, StringField, DecimalField, IntField,
-    BoolField, UserError, Currency, NotAvailable, EnumField, Enum,
-    empty, find_object,
+    BoolField, UserError, Currency, NotAvailable, EnumField, Enum, empty,
+    find_object, NotLoaded, NotLoadedType, NotAvailableType
 )
 from woob.capabilities.date import DateField
 from woob.capabilities.collection import CapCollection
@@ -35,11 +35,20 @@ from woob.exceptions import BrowserIncorrectPassword
 __all__ = [
     'CapBank', 'BaseAccount', 'Account', 'Loan', 'Transaction', 'AccountNotFound',
     'AccountType', 'AccountOwnership', 'Balance', 'AccountSchemeName', 'TransactionCounterparty',
-    'AccountOwnerProfile', 'IdentityParty', 'AccountParty', 'AccountIdentification',
-    'PartyRole', 'CapAccountCheck',
+    'AccountOwnerProfile', 'PartyIdentity', 'AccountParty', 'AccountIdentification',
+    'PartyRole', 'CapAccountCheck', 'NoAccountsException',
 ]
 
 
+class NoAccountsException(Exception):
+    """
+    Raised by :meth:`CapBank.iter_accounts()` if we are sure there is no accounts.
+
+    Sometimes we can't parse find accounts on websites but that's a scraping
+    error. To attest we know that's a real case, this exception is raised.
+    """
+
+
 class ObjectNotFound(UserError):
     pass
 
@@ -49,8 +58,8 @@ class AccountNotFound(ObjectNotFound):
     Raised when an account is not found.
     """
 
-    def __init__(self, msg='Account not found'):
-        super(AccountNotFound, self).__init__(msg)
+    def __init__(self, msg: str = 'Account not found'):
+        super().__init__(msg)
 
 
 class BaseAccount(BaseObject, Currency):
@@ -62,15 +71,21 @@ class BaseAccount(BaseObject, Currency):
     currency =       StringField('Currency', default=None)
     bank_name =      StringField('Bank Name', mandatory=False)
 
-    def __init__(self, id='0', url=None):
-        super(BaseAccount, self).__init__(id, url)
+    # TODO add iban field here
+
+    def __init__(
+        self,
+        id: str = '0',
+        url: str | NotLoadedType | NotAvailableType = NotLoaded
+    ):
+        super().__init__(id, url)
 
     @property
-    def currency_text(self):
+    def currency_text(self) -> str:
         return Currency.currency2txt(self.currency)
 
     @property
-    def ban(self):
+    def ban(self) -> str | NotAvailableType:
         """ Bank Account Number part of IBAN"""
         if not self.iban:
             return NotAvailable
@@ -125,27 +140,27 @@ class AccountType(Enum):
     "Crowdlending accounts"
 
 
-class AccountOwnerType(object):
+class AccountOwnerType:
     """
     Specifies the usage of the account
     """
-    PRIVATE = u'PRIV'
+    PRIVATE = 'PRIV'
     """private personal account"""
-    ORGANIZATION = u'ORGA'
+    ORGANIZATION = 'ORGA'
     """professional account"""
-    ASSOCIATION = u'ASSO'
+    ASSOCIATION = 'ASSO'
     """association account"""
 
 
-class AccountOwnership(object):
+class AccountOwnership:
     """
     Relationship between the credentials owner (PSU) and the account
     """
-    OWNER = u'owner'
+    OWNER = 'owner'
     """The PSU is the account owner"""
-    CO_OWNER = u'co-owner'
+    CO_OWNER = 'co-owner'
     """The PSU is the account co-owner"""
-    ATTORNEY = u'attorney'
+    ATTORNEY = 'attorney'
     """The PSU is the account attorney"""
 
 
@@ -204,7 +219,6 @@ class AccountIdentification(BaseObject):
     - scheme_name: Name of the account scheme type
     - identification: ID of the account
     """
-
     scheme_name = EnumField('Name of the account scheme type', AccountSchemeName, default=None)
     identification = StringField('ID of the account', default=None)
 
@@ -212,7 +226,7 @@ class AccountIdentification(BaseObject):
         return f'<AccountIdentification scheme_name={self.scheme_name} identification={self.identification}>'
 
 
-class IdentityParty(BaseObject):
+class PartyIdentity(BaseObject):
     """
     Defines the identity of a party:
     - full_name: Full name of the party
@@ -234,24 +248,20 @@ class IdentityParty(BaseObject):
     role = EnumField('Role of the party.', PartyRole, default=ROLE_UNKNOWN)
 
     def __repr__(self):
-        return f'<IdentityParty full_name={self.full_name} role={self.role} is_user={self.is_user}>'
+        return f'<PartyIdentity full_name={self.full_name} role={self.role} is_user={self.is_user}>'
 
 
 class AccountParty(BaseObject):
     """
-    Defines all the informations related to an account party:
-    - name: Name of the account
-    - type: Type of the account
-    - identities: list of IdentityParty elements
-    - identifications : list of AccountIdentification elements
+    Defines all the information related to an account party:
+    - party_identities: list of PartyIdentity elements
+    - account_identifications : list of AccountIdentification elements
     """
-    name = StringField('Name of the account', default=None)
-    type = StringField('Type of the account', default=None)
-    identities = Field('Identities of the party', list, default=[])
-    identifications = Field('Informations about the account', list, default=[])
+    party_identities = Field('Identities of the account party', list, default=[])
+    account_identifications = Field('Identification information of the account', list, default=[])
 
     def __repr__(self):
-        return f'<AccountParty name={self.name} type={self.type} identities={self.identities} identifications={self.identifications}>'
+        return f'<AccountParty party_identities={self.party_identities} account_identifications={self.account_identifications}>'
 
 
 class Account(BaseAccount):
@@ -400,6 +410,7 @@ class TransactionType(Enum):
     CASH_DEPOSIT  = 10
     CARD_SUMMARY  = 11
     DEFERRED_CARD = 12
+    INSTANT       = 13
 
 
 class Transaction(BaseObject):
@@ -419,6 +430,7 @@ class Transaction(BaseObject):
     TYPE_CASH_DEPOSIT  = TransactionType.CASH_DEPOSIT
     TYPE_CARD_SUMMARY  = TransactionType.CARD_SUMMARY
     TYPE_DEFERRED_CARD = TransactionType.DEFERRED_CARD
+    TYPE_INSTANT       = TransactionType.INSTANT
 
     date =      DateField('Debit date on the bank statement')
     rdate =     DateField('Real date, when the payment has been made; usually extracted from the label or from credit card info')
@@ -429,6 +441,7 @@ class Transaction(BaseObject):
     category =  StringField('Category of the transaction')
     label =     StringField('Pretty label')
     amount = DecimalField('Net amount of the transaction, used to compute account balance')
+    coming = BoolField('True if the transaction is not yet booked')
 
     card =              StringField('Card number (if any)')
     commission =        DecimalField('Commission part on the transaction (in account currency)')
@@ -451,14 +464,14 @@ class Transaction(BaseObject):
     def __repr__(self):
         return "<Transaction date=%r label=%r amount=%r>" % (self.date, self.label, self.amount)
 
-    def unique_id(self, seen=None, account_id=None):
+    def unique_id(self, seen: set | None = None, account_id: str | None = None) -> str:
         """
         Get an unique ID for the transaction based on date, amount and raw.
 
-        :param seen: if given, the method uses this dictionary as a cache to
+        :param seen: if given, the method uses this set as a cache to
                      prevent several transactions with the same values to have the same
                      unique ID.
-        :type seen: :class:`dict`
+        :type seen: :class:`set`
         :param account_id: if given, add the account ID in data used to create
                            the unique ID. Can be useful if you want your ID to be unique across
                            several accounts.
@@ -500,6 +513,7 @@ class CapBank(CapCollection, CapCredentialsCheck):
         has a browser, execute its do_login if it has one and then see if no error pertaining to the creds is raised.
         If any other unexpected error occurs, we don't know whether the creds are correct or not.
         """
+        # TODO move this in a specific capability
         if getattr(self, 'BROWSER', None) is None:
             raise NotImplementedError()
 
@@ -510,7 +524,7 @@ class CapBank(CapCollection, CapCredentialsCheck):
 
         return True
 
-    def iter_resources(self, objs, split_path):
+    def iter_resources(self, objs: List[BaseObject], split_path: List[str]) -> Iterable[BaseObject]:
         """
         Iter resources.
 
@@ -526,9 +540,9 @@ class CapBank(CapCollection, CapCredentialsCheck):
         if Account in objs:
             self._restrict_level(split_path)
 
-            return self.iter_accounts()
+            yield from self.iter_accounts()
 
-    def iter_accounts(self):
+    def iter_accounts(self) -> Iterable[Account]:
         """
         Iter accounts.
 
@@ -536,7 +550,7 @@ class CapBank(CapCollection, CapCredentialsCheck):
         """
         raise NotImplementedError()
 
-    def get_account(self, id):
+    def get_account(self, id: str) -> Account | None:
         """
         Get an account from its ID.
 
@@ -547,26 +561,41 @@ class CapBank(CapCollection, CapCredentialsCheck):
         """
         return find_object(self.iter_accounts(), id=id, error=AccountNotFound)
 
-    def iter_history(self, account):
+    def iter_history(self, account: Account) -> Iterable[Transaction]:
         """
-        Iter history of transactions on a specific account.
+        Iter history of transactions of a specific account.
 
         :param account: account to get history
         :type account: :class:`Account`
         :rtype: iter[:class:`Transaction`]
         :raises: :class:`AccountNotFound`
         """
-        raise NotImplementedError()
+        return self.iter_transactions(account, with_coming=False)
 
-    def iter_coming(self, account):
+    def iter_coming(self, account: Account) -> Iterable[Transaction]:
         """
-        Iter coming transactions on a specific account.
+        Iter coming transactions of a specific account.
 
         :param account: account to get coming transactions
         :type account: :class:`Account`
         :rtype: iter[:class:`Transaction`]
         :raises: :class:`AccountNotFound`
         """
+        return self.iter_transactions(account, with_history=False)
+
+    def iter_transactions(
+        self, account: Account, *, with_history: bool = True, with_coming: bool = True
+    ) -> Iterable[Transaction]:
+        """
+        Iter all transactions (history and coming) of a specific account.
+
+        :param account: account to get transactions
+        :param with_history: if False, booked transactions will not be returned
+        :param with_coming: if False, coming transactions will not be returned
+        :type account: :class:`Account`
+        :rtype: iter[:class:`Transaction`]
+        :raises: :class:`AccountNotFound`
+        """
         raise NotImplementedError()
 
 
@@ -575,15 +604,12 @@ class CapAccountCheck(Capability):
     Capability to get accounts parties information.
 
     The expected structure is the following:
-    - AccountParty object
-        * name
-        * type
-        * identities (list of IdentityParty elements):
-            * full name
-            * role
-            * is_user
-        * identifications (list of type AccountIdentification elements):
-            * scheme name
-            * identification
+        - AccountParty object
+            * party_identities (list of PartyIdentity elements):
+                * full name
+                * role
+                * is_user
+            * account_identifications (list of type AccountIdentification elements):
+                * scheme name
+                * identification
     """
-    pass
